==> haskell-warp-3.3.30-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.3.30
visibility:           public
id:                   warp-3.3.30-JHvnV9TPjHLAZrkQ02GidN
key:                  warp-3.3.30-JHvnV9TPjHLAZrkQ02GidN
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  1582a6885e518fee87976cc340093394
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-3.3.30
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-3.3.30
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-3.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.3.30-JHvnV9TPjHLAZrkQ02GidN
depends:
    array-0.5.4.0 auto-update-0.1.6-HnR5KSCoJMXDKDW6OvAZBk
    base-4.17.2.1 bsb-http-chunked-0.0.0.4-CXDvYseqZzBDDXDx3yYDPw
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-FHIyOcPiW8PKDdKhHarL3Z
    containers-0.6.7 crypton-x509-1.7.7-KM6Kko3Hfc7LB5j0oSGqyk
    ghc-prim-0.9.1 hashable-1.4.4.0-32D8TF68xTpFTCUtV1slOl
    http-date-0.0.11-CbWejWJYJkpA3A3bNd9Whs
    http-types-0.12.4-D9QL6TIrURkF1xQ74r64OS
    http2-4.2.1-DyzU07NcvfbFoaOCAqWyz7
    iproute-1.7.15-2foa2cIYP5cBd91LeusI62
    network-3.1.4.0-7upd0S3IeIT8lWw9Gu9EjE
    recv-0.1.1-4wlkBqHps1EFCObuEBpudi
    simple-sendfile-0.2.32-6wrHHLuUXzi23w3lgNIAdp stm-2.5.1.0
    streaming-commons-0.2.3.0-DACqGMxZDljH0rbiKcQ7Nw text-2.0.2
    time-manager-0.0.1-ATFhsWjt8v477VpEHsSfxT unix-2.7.3
    unliftio-0.2.25.1-90yOZ4mDd378K3VObKxqKs
    vault-0.3.1.5-8anlucvvM0AFp9vCZGDO11
    wai-3.2.4-FH3YusaDMJ8DwjWcoaMJC word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.3.30-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.3.30
visibility:           public
id:                   warp-3.3.30-6f86FwsrA0q9gyhbhZhd7N
key:                  warp-3.3.30-6f86FwsrA0q9gyhbhZhd7N
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  dc8322d228487b9fd87a8cb95d60ad7a
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-3.3.30
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-3.3.30
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-3.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.3.30-6f86FwsrA0q9gyhbhZhd7N
depends:
    array-0.5.4.0 auto-update-0.1.6-58cUX3eRof6DEapr1heHzL
    base-4.17.2.1 bsb-http-chunked-0.0.0.4-8gi7Q90L8uNCbrpaP4PIk0
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-FtXwbgcyUdT58mvaxnolJS
    containers-0.6.7 crypton-x509-1.7.7-LQsOJOeijoVKAs6avnFKjN
    ghc-prim-0.9.1 hashable-1.4.4.0-Htybuq5UDQvAvffgJDQoKe
    http-date-0.0.11-TZQH05CY4V6BMEINbtlTE
    http-types-0.12.4-KxfEKIoLDdBKlrGUyHct4y
    http2-4.2.1-BsNp1RnGXEkK1t9OBeZlxJ
    iproute-1.7.15-e1zKSAL8tO2scPmstVWin
    network-3.1.4.0-HbZCj3UHcZsFvn6ftFrD4m
    recv-0.1.1-FUAi3ygNUtEOaY3jNIgoQ
    simple-sendfile-0.2.32-5kDqUzqIkyn3ylwVGOfMvf stm-2.5.1.0
    streaming-commons-0.2.3.0-6BG7IUO9tyzFcAlz4O6I16 text-2.0.2
    time-manager-0.0.1-7XqZ0FC0r113pKRulihcnj unix-2.7.3
    unliftio-0.2.25.1-CJQK5KnE2olHnUQXP11pzl
    vault-0.3.1.5-BQ3GCz3hemaFHrE1GoYhu4
    wai-3.2.4-5eTAAfrYzv8Cj5jt7kPDLd word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
